@@ -67,25 +67,25 @@
 
 
 qpcrTTEST <- function(x,numberOfrefGenes, paired = FALSE, var.equal = TRUE) {
-
+  
   colnames(x)[1] <- "Condition"
   colnames(x)[2] <- "Gene"
   colnames(x)[3] <- "E"
   colnames(x)[4] <- "Ct"
-
-
-
-
+  
+  
+  
+  
   r <- nrow(x)/(2 * length(unique(x$Gene)))
-
+  
   if(!all(r %% 1 == 0)) {
     stop("Error: Replicates are not equal for all Genes!")
   } else {
-
-
-
+    
+    
+    
     x <- data.frame(x, wCt = log2(x$E) * x$Ct)
-
+    
     if(numberOfrefGenes == 1) {
       x <- x
     } else {
@@ -95,24 +95,33 @@ qpcrTTEST <- function(x,numberOfrefGenes, paired = FALSE, var.equal = TRUE) {
       x$wCt[a:b] <- mwCT
       x <- x[-((a+(2*r)):(b+(2*r))),]
     }
-
     
     
     
-
+    
+    
     
     
     GENE <- x$Gene
-
-
+    
+    
     levels_to_compare <- unique(GENE)[-length(unique(GENE))]
-    res <- matrix(nrow = length(levels_to_compare), ncol=7)
+    res <- matrix(nrow = length(levels_to_compare), ncol = 7)
     colnames(res) <- c("Gene", "dif", "FC", "LCL", "UCL", "pvalue", "se")
+    subset_df <- data.frame(group = character(), Gene = character(), wDCt = numeric())
+    for (i in 1:length(levels_to_compare)) {
+      subset_df <- rbind(subset_df, 
+                         data.frame(group = x[GENE == levels_to_compare[i], "Condition"],
+                                    Gene = levels_to_compare[i],
+                                    wDCt = x[GENE == levels_to_compare[i], "wCt"] - x[GENE == utils::tail(unique(GENE), 1), "wCt"]))
+    }
+    
+    
+    
+    
     subset <- matrix(NA, nrow = 2 * r, ncol=length(levels_to_compare))
     ttest_result <- vector("list", length(levels_to_compare))
     
-
-
     for (i in 1:length(levels_to_compare)) {
       subset[,i] <- x[GENE == levels_to_compare[i], "wCt"] - x[GENE == utils::tail(unique(GENE), 1), "wCt"]
       ttest_result[[i]] <- stats::t.test(subset[(r + 1):(2 * r), i], subset[1:r, i], paired = paired, var.equal = var.equal)
@@ -124,7 +133,7 @@ qpcrTTEST <- function(x,numberOfrefGenes, paired = FALSE, var.equal = TRUE) {
                     round(2^(-ttest_result[[i]]$conf.int[1]), 4), # Upper error bar point
                     round(ttest_result[[i]]$p.value, 4),
                     round(stats::sd(subset[(r+1):(2*r),i])/sqrt(r), 4))
-
+      
     }
     res <- as.data.frame(res)
     res$FC <- as.numeric(res$FC)
@@ -135,7 +144,7 @@ qpcrTTEST <- function(x,numberOfrefGenes, paired = FALSE, var.equal = TRUE) {
                       Upper.se = round(2^(log2(res$FC) + res$se), 4))
     
     Raw_df <- melt(subset, value.name = "wDCt")[-1]
-    res <- list(Raw_data = Raw_df, Result = res)
+    res <- list(Raw_data = subset_df, Result = res)
     return(res)
   }
 }
